@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13367 2021-12-24 04:53:31Z Mint $
+# $Id: Backends.py 13428 2022-04-25 17:43:01Z Jason $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Mint $
-# $Date: 2021-12-24 12:53:31 +0800 (Fri, 24 Dec 2021) $
-# $Revision: 13367 $
+# $Author: Jason $
+# $Date: 2022-04-26 01:43:01 +0800 (Tue, 26 Apr 2022) $
+# $Revision: 13428 $
 
 import re
 import json
@@ -52,6 +52,8 @@ class TracBackend(ModelBackend):
                 email = user.get("email")
             if ht.check_password(username, password):
                 return (True, email)
+        else:
+            raise PermissionDenied("No such user, please try again")
         return (False, None)
 
     def authenticate(self, request, username=None, password=None, **kwargs):
