@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_app.py 12039 2020-04-04 08:25:59Z Lavender $
+# $Id: start_app.py 13380 2022-01-23 02:32:54Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-04 16:25:59 +0800 (Sat, 04 Apr 2020) $
-# $Revision: 12039 $
+# $Date: 2022-01-23 10:32:54 +0800 (Sun, 23 Jan 2022) $
+# $Revision: 13380 $
 
 import os
 import sys
 import datetime
 import shutil
+import subprocess
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
@@ -85,7 +86,8 @@ class Command(BaseCommand):
                 import scrapy
             except Exception as e:
                 result = os.system("pip install scrapy")
-            result = os.system("scrapy startproject %s" % SCRAPY_PROJECT_NAME)
+            subprocess.run("scrapy startproject %s" % SCRAPY_PROJECT_NAME, 
+                shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
 
             appPath = os.path.join(name)
             cfgPath = os.path.join(SCRAPY_PROJECT_NAME, "scrapy.cfg")
